pub fn collect_partials(
store: &CrossPartitionAggregateStore,
group_key: &[u8],
) -> Vec<PartialAggregate>Expand description
Collect and deserialize partials for a group key from a
CrossPartitionAggregateStore.
pub fn collect_partials(
store: &CrossPartitionAggregateStore,
group_key: &[u8],
) -> Vec<PartialAggregate>Collect and deserialize partials for a group key from a
CrossPartitionAggregateStore.