pub struct ConnectorCheckpoint {
pub offsets: HashMap<String, String>,
pub metadata: HashMap<String, String>,
pub input_channels: Option<Vec<Vec<u8>>>,
pub source_assignment_version: Option<NonZeroU64>,
}Expand description
Connector-owned offset map stored at the exact checkpoint cut.
Fields
offsets: HashMap<String, String>Connector-specific offsets.
metadata: HashMap<String, String>Connector metadata required to interpret the offsets.
input_channels: Option<Vec<Vec<u8>>>Canonically ordered opaque identities of the input channels owned by this cut.
source_assignment_version: Option<NonZeroU64>Source-assignment version owning this cut, when applicable.
Implementations