pub fn checkpoint_artifact_identity_sha256(
inventory: &CheckpointArtifactInventory,
chunk: StateChunkId,
) -> Result<String, CheckpointStoreError>Expand description
SHA-256 binding one active artifact inventory to one exact participant object namespace.
Errors
Returns an error when the inventory or object identity is not canonical.