pub struct CheckpointManifestAbortSeal {
pub original_manifest: Option<(CheckpointManifest, Bytes)>,
pub sink_artifact_intent_protocol: bool,
pub open_sink_artifact_intents: Vec<CheckpointSinkArtifactIntent>,
pub sink_cleanup_complete: bool,
}Expand description
Durable state returned after sealing one aborted participant manifest.
Fields
original_manifest: Option<(CheckpointManifest, Bytes)>Original prepared manifest, when that participant completed persistence.
sink_artifact_intent_protocol: boolWhether absence of an intent proves this participant never entered begin_epoch.
open_sink_artifact_intents: Vec<CheckpointSinkArtifactIntent>Begin-time intents retained when phase one never produced a participant manifest.
sink_cleanup_complete: boolWhether exact connector cleanup completed before node data may be sealed.