pub struct CommittedCheckpointRef {
pub epoch: u64,
pub checkpoint_id: u64,
pub sha256: String,
pub len: u64,
}Expand description
Content-addressed reference carried by a terminal Commit outcome.
Fields
epoch: u64Exact epoch encoded by the index and its object path.
checkpoint_id: u64Exact checkpoint ID encoded by the index and its object path.
sha256: StringSHA-256 of the exact canonical index body.
len: u64Exact canonical index body length.
Implementations