CommittedParticipantRef

Struct CommittedParticipantRef 

pub struct CommittedParticipantRef {
    pub participant_id: u64,
    pub manifest_len: u64,
    pub manifest_sha256: String,
    pub node_data_len: u64,
    pub node_data_sha256: String,
}
Exact immutable participant objects admitted into a committed cut.

Fields

participant_id: u64

Stable participant node identifier.

manifest_len: u64

Exact persisted manifest length.

manifest_sha256: String

SHA-256 of the exact persisted manifest bytes.

node_data_len: u64

Exact immutable node-data object length.

node_data_sha256: String

SHA-256 of the complete immutable node-data object.

Implementations

Source

impl CommittedParticipantRef

pub fn from_manifest( manifest: &CheckpointManifest, persisted_manifest: &[u8], ) -> Result<Self, String>

Bind an already validated manifest and its exact persisted bytes.

Errors

Returns an error if the manifest bytes do not encode the supplied manifest.

pub fn validate(&self) -> Result<(), String>

Validate the reference encoding.

Errors

Returns an error when an identifier, length, or digest is invalid.

pub fn verify_manifest( &self, manifest: &CheckpointManifest, persisted_manifest: &[u8], ) -> Result<(), String>

Verify one loaded manifest against this exact reference.

Errors

Returns an error when the manifest or its bytes differ from this reference.