pub enum CheckpointStorageScope {
Volatile,
NodeDurable,
ClusterShared,
}Expand description
Failure domain of a checkpoint object-store URL.
Variants
Volatile
No durable checkpoint namespace can be proven from the URL.
NodeDurable
A local filesystem namespace survives process restart on one node.
A remote object-store namespace is shared by cluster participants.
Implementations