pub fn file_url_path(url: &str) -> Result<PathBuf, ObjectStoreBuilderError>Expand description
Absolute local filesystem path from a canonical lowercase file:// URL.
Errors
Returns ObjectStoreBuilderError::InvalidUrl for a non-file scheme,
remote authority, relative path, query, fragment, or invalid encoding.