pub struct RecoveryCapsuleRef {
pub epoch: u64,
pub checkpoint_id: u64,
pub sha256: String,
pub len: u64,
}Expand description
Content-addressed reference carried by a durable checkpoint outcome.
Fields
epoch: u64Exact epoch encoded by the capsule and its object path.
checkpoint_id: u64Exact checkpoint attempt encoded by the capsule and its object path.
sha256: StringLowercase hexadecimal SHA-256 of the exact canonical JSON body.
len: u64Exact canonical JSON body length.
Implementations