pub struct PartitionFrontier {
pub partition: OutputPartitionId,
pub through_sequence: PartitionSequence,
}Expand description
First partition sequence not covered by a committed checkpoint.
Fields
partition: OutputPartitionIdStable vnode output partition.
through_sequence: PartitionSequenceEvery sequence below this exclusive frontier is covered by the checkpoint.