pub struct StreamGeneration(/* private fields */);Expand description
Durable identity of one catalog stream incarnation.
Implementations
Sourceimpl StreamGeneration
impl StreamGeneration
Sourcepub fn derive(
deployment_id: Uuid,
catalog_generation: u64,
stream_name: &str,
canonical_query: &str,
pipeline_identity: &PipelineIdentity,
) -> Self
pub fn derive( deployment_id: Uuid, catalog_generation: u64, stream_name: &str, canonical_query: &str, pipeline_identity: &PipelineIdentity, ) -> Self
Derive a generation from the durable deployment, catalog incarnation, query, and pipeline.
Sourcepub const fn from_digest(digest: SubscriptionDigest) -> Self
pub const fn from_digest(digest: SubscriptionDigest) -> Self
Construct from a fixed digest, for persisted metadata and tests.
Sourcepub const fn digest(self) -> SubscriptionDigest
pub const fn digest(self) -> SubscriptionDigest
Exact generation digest.