pub struct CatalogManifestStore { /* private fields */ }Expand description
Catalog view over the same append-only authority used for leader fencing.
Implementations
Sourceimpl CatalogManifestStore
impl CatalogManifestStore
Sourcepub fn new(authority: Arc<LeaderLeaseStore>) -> Self
pub fn new(authority: Arc<LeaderLeaseStore>) -> Self
Share the exact append-only authority used by the leader lease manager.
Sourcepub async fn load(
&self,
) -> Result<Option<CatalogManifest>, CatalogManifestError>
pub async fn load( &self, ) -> Result<Option<CatalogManifest>, CatalogManifestError>
Load the sealed catalog, or None before the first successful seal.
Errors
Fails on object-store I/O, malformed JSON, or an invalid inventory.
Sourcepub async fn seal(
&self,
manifest: &CatalogManifest,
proof: &LeaderProof,
) -> Result<CatalogSealOutcome, CatalogManifestError>
pub async fn seal( &self, manifest: &CatalogManifest, proof: &LeaderProof, ) -> Result<CatalogSealOutcome, CatalogManifestError>
CAS-append the first inventory under an exact leader proof.
A concurrent exact inventory is idempotent. Any different winner fails closed.
Errors
Fails for an invalid proposal, divergent winner, or object-store I/O.