pub enum RecoveryFaultReportOutcome {
Active,
AlreadyCleared,
CoveredByNewerRequest,
}Expand description
Durable disposition of one process-local recovery-fault request.
Variants
Active
The exact request is the active fault for this stable node.
AlreadyCleared
The exact request was already atomically covered by a committed recovery Release.
CoveredByNewerRequest
A newer request from the same process already superseded this request.