pub enum RecordAssignmentRecoveryDecisionResult {
Created(AssignmentRecoveryDecision),
Unchanged(AssignmentRecoveryDecision),
Conflict {
winner: AssignmentRecoveryDecision,
},
}Expand description
Result of admitting a recovery decision through the shared authority sequence.
Variants
Created(AssignmentRecoveryDecision)
This call created the immutable decision.
Unchanged(AssignmentRecoveryDecision)
The same decision was already durable.
Conflict
Another recovery decision already won for this target version.
Fields

winner: AssignmentRecoveryDecisionImmutable winner.