pub struct LeaseDeadline { /* private fields */ }Expand description
Process-local monotonic deadline for a renewable durable lease.
Implementations
Sourceimpl LeaseDeadline
impl LeaseDeadline
Sourcepub fn is_live(&self) -> bool
pub fn is_live(&self) -> bool
Whether the holder remains inside its last successful renewal deadline.
Sourcepub async fn wait_until_expired(&self)
pub async fn wait_until_expired(&self)
Wait until the deadline expires naturally or is terminally fenced.