pub struct VerifiedClusterNamespaces { /* private fields */ }Expand description
Exact object-store handles admitted by a successful cluster namespace proof.
Implementations
Sourceimpl VerifiedClusterNamespaces
impl VerifiedClusterNamespaces
Sourcepub fn checkpoint_store(&self) -> Arc<dyn ObjectStore> ⓘ
pub fn checkpoint_store(&self) -> Arc<dyn ObjectStore> ⓘ
Return the exact checkpoint store handle covered by the proof.
Sourcepub fn state_store(&self) -> Arc<dyn ObjectStore> ⓘ
pub fn state_store(&self) -> Arc<dyn ObjectStore> ⓘ
Return the exact state store handle covered by the proof.
Sourcepub const fn local_participant(&self) -> CheckpointParticipant
pub const fn local_participant(&self) -> CheckpointParticipant
Return the process identity that produced this proof.