set_cluster_tls

Function set_cluster_tls 

pub fn set_cluster_tls(tls: ClusterTls) -> Result<(), String>
Install process-wide control-plane TLS before any cluster transport is constructed.

Reinstalling byte-identical material is idempotent. Different material, or installation after plaintext was explicitly selected or used by a transport, fails closed.

Errors

Returns an error when transport mode is already plaintext or different TLS material is active.