pub struct CompilerCache { /* private fields */ }Expand description
Cache for compiled pipelines, keyed by a hash of pipeline stages.
Implementations
Sourceimpl CompilerCache
impl CompilerCache
Sourcepub fn new(max_entries: usize) -> Result<Self, CompileError>
pub fn new(max_entries: usize) -> Result<Self, CompileError>
Creates a new compiler cache with the given maximum number of entries.
Errors
Returns CompileError if the JIT context cannot be initialized.
Sourcepub fn get_or_compile(
&mut self,
pipeline: &Pipeline,
) -> Result<Arc<CompiledPipeline>, CompileError>
pub fn get_or_compile( &mut self, pipeline: &Pipeline, ) -> Result<Arc<CompiledPipeline>, CompileError>
Returns a cached compiled pipeline, or compiles and caches it.
Errors
Returns CompileError if compilation fails.