pub enum SubmitResult {
Emitted,
Filtered,
}Expand description
Result of submitting an event row to a streaming query.
Variants
Emitted
At least one pipeline emitted output for this row.
Filtered
All pipelines filtered out this row.