pub struct ConditionalPut {
pub partition_id: u32,
pub expected_epoch: u64,
pub writer_node: NodeId,
}Expand description
Conditional PUT parameters for object storage epoch fencing.
Used when writing checkpoint data to S3/GCS/Azure to ensure that only the current epoch owner can write.
Fields
partition_id: u32The partition being checkpointed.
expected_epoch: u64The epoch that must match for the write to succeed.
writer_node: NodeIdThe node that is writing.
Implementations