pub enum GcsCredentialError {
UnreadableApplicationCredentials,
ApplicationCredentialsTooLarge,
InvalidApplicationCredentialsJson,
InvalidExternalAccountField(&'static str),
UnsupportedApplicationCredentialType,
InvalidExternalAccountConfiguration,
TokenAcquisition,
EmptyAccessToken,
}Expand description
A redacted failure while selecting Google application credentials.
Variants
UnreadableApplicationCredentials
The selected credential file could not be read.
ApplicationCredentialsTooLarge
The selected credential file exceeds the bounded configuration size.
InvalidApplicationCredentialsJson
The selected credential file is not valid JSON.
InvalidExternalAccountField(&'static str)
A required external-account field was missing or had the wrong type.
UnsupportedApplicationCredentialType
The selected ADC credential type is not supported by the pinned client.
InvalidExternalAccountConfiguration
Google’s credential provider rejected the external-account configuration.
TokenAcquisition
Google’s refreshable provider failed to acquire an access token.
EmptyAccessToken
Google’s refreshable provider returned an unusable access token.