debug_assert_priority

Macro debug_assert_priority 

macro_rules! debug_assert_priority {
    ($class:expr) => { ... };
}
Assert that the current thread is running in the expected priority class.

In debug builds, panics if the current priority class does not match. In release builds, this is a no-op.