pub struct RetractableCountAccumulator { /* private fields */ }Expand description
Retractable count accumulator.
Uses signed integer to support negative counts from retractions. In a correct pipeline, the count should never go negative.
Implementations