pub struct CheckpointRoutePlan {
pub local: Vec<LocalRoute>,
pub remote: Vec<RemoteRoute>,
}Expand description
Complete, conserving routing plan staged before any remote send.
Fields
local: Vec<LocalRoute>Local chunks, ordered by vnode and then input row.
remote: Vec<RemoteRoute>Remote chunks, ordered by owner and then input row.