is_scope_cancelled

Function is_scope_cancelled 

pub fn is_scope_cancelled(error: &Error) -> bool
Whether an outbound shuffle operation was cancelled by an assignment or recovery scope transition. Generic connection cancellation is deliberately not classified as a scope change.