pub struct SealedCommitDescriptorWriter {
pub participant: CheckpointParticipant,
pub assignment_certificate_digest: [u8; 32],
pub leader_proof: LeaderProof,
}Expand description
Exact process and leader term that produced one immutable commit descriptor.
Fields
participant: CheckpointParticipantBoot-exact process that wrote the descriptor.
assignment_certificate_digest: [u8; 32]SHA-256 of the exact checkpoint assignment certificate.
leader_proof: LeaderProofDurable leader term that initiated the checkpoint attempt.
Implementations
Sourceimpl SealedCommitDescriptorWriter
impl SealedCommitDescriptorWriter
Sourcepub fn matches_fence(&self, fence: &CheckpointAssignmentFence) -> bool
pub fn matches_fence(&self, fence: &CheckpointAssignmentFence) -> bool
Whether this writer and checkpoint authority exactly match fence.