pub fn peer_owners(registry: &VnodeRegistry, self_id: NodeId) -> Vec<NodeId>Expand description
Distinct assigned nodes other than self_id, sorted by id — the peer set a
node fans checkpoint barriers and shuffle data out to.
pub fn peer_owners(registry: &VnodeRegistry, self_id: NodeId) -> Vec<NodeId>Distinct assigned nodes other than self_id, sorted by id — the peer set a
node fans checkpoint barriers and shuffle data out to.