SubscriptionMessage

Enum SubscriptionMessage 

pub enum SubscriptionMessage<T> {
    Record(T),
    Batch(RecordBatch),
    Watermark(i64),
}
Message types that can be received from a subscription.

Variants



Record(T)

A single record.



Batch(RecordBatch)

A batch of records.



Watermark(i64)

A watermark timestamp.

Implementations

Source

impl<T: Record> SubscriptionMessage<T>

pub fn is_record(&self) -> bool

Returns true if this is a record message.

pub fn is_batch(&self) -> bool

Returns true if this is a batch message.

pub fn is_watermark(&self) -> bool

Returns true if this is a watermark message.

pub fn to_batch(self) -> Option<RecordBatch>

Converts to a RecordBatch if this is a data message.

pub fn watermark(&self) -> Option<i64>

Returns the watermark timestamp if this is a watermark message.