pub struct Subscription<T: Record> { /* private fields */ }Expand description
A subscription to a streaming sink. Each subscriber independently receives every message via broadcast.
Implementations
Sourceimpl<T: Record> Subscription<T>
impl<T: Record> Subscription<T>
Sourcepub fn poll(&mut self) -> Option<RecordBatch>
pub fn poll(&mut self) -> Option<RecordBatch>
Non-blocking poll. Returns the next batch, skipping watermarks.
Returns None on empty or closed channel. Check is_disconnected()
to distinguish.
Sourcepub async fn recv_async(&mut self) -> Result<RecordBatch, RecvError>
pub async fn recv_async(&mut self) -> Result<RecordBatch, RecvError>
Async receive. Awaits the next batch, skipping watermarks.
Errors
Returns RecvError::Disconnected if the source has been dropped.
Sourcepub fn recv(&mut self) -> Result<RecordBatch, RecvError>
pub fn recv(&mut self) -> Result<RecordBatch, RecvError>
Blocking receive. Uses tokio’s waker-based blocking_recv.
Errors
Returns RecvError::Disconnected if the source has been dropped.
Sourcepub fn recv_timeout(
&mut self,
timeout: Duration,
) -> Result<RecordBatch, RecvError>
pub fn recv_timeout( &mut self, timeout: Duration, ) -> Result<RecordBatch, RecvError>
Blocking receive with timeout. Requires a tokio runtime in the current thread context.
Errors
Returns RecvError::Timeout or RecvError::Disconnected.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if the channel has been observed closed.