pub struct TimerRegistration {
pub id: u64,
pub timestamp: i64,
pub key: Option<TimerKey>,
pub operator_index: Option<usize>,
}Expand description
A timer registration for delayed processing.
Timers are used by operators to schedule future actions, typically for window triggering or timeouts.
Fields
id: u64Unique timer ID
timestamp: i64Scheduled timestamp (event time, in milliseconds)
key: Option<TimerKey>Timer key (for keyed operators).
Uses TimerKey (SmallVec) to avoid heap allocation for keys up to 16 bytes.
operator_index: Option<usize>The index of the operator that registered this timer