pub struct HllSketch { /* private fields */ }Expand description
Minimal HyperLogLog sketch for approximate distinct counting.
Uses 2^precision registers. Default precision is 8 (256 registers,
~256 bytes of memory, ~2% standard error).
Wire Format
[precision: u8][registers: u8 * (2^precision)]
Implementations
Sourceimpl HllSketch
impl HllSketch
Sourcepub fn with_precision(precision: u8) -> Self
pub fn with_precision(precision: u8) -> Self
Create a new empty sketch with the given precision.
Allocates 2^precision registers.
Panics
Panics if precision is not in the range 4..=18.
Sourcepub fn merge(&mut self, other: &Self)
pub fn merge(&mut self, other: &Self)
Merge another sketch into this one (HLL union).
Panics
Panics if the two sketches have different precisions.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, TwoPhaseError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, TwoPhaseError>
Sourcepub fn num_registers(&self) -> usize
pub fn num_registers(&self) -> usize
Number of registers (2^precision).