pub fn channel_progress_frontier(
channels: &[ChannelProgress],
) -> Result<Option<i64>, String>Expand description
Numeric frontier retained by a channel cut, including an all-idle cut.
Errors
Returns an error when the channel cut contains an invalid watermark sentinel.