pub fn canonical_json_bytes<T: Serialize>(value: &T) -> Result<Vec<u8>, Error>Expand description
Serialize any JSON-compatible value with recursively sorted object keys.
This is the canonical digest input for manifests and readiness records containing HashMaps.
Errors
Returns a JSON error when value cannot be represented as JSON.