pub fn owned_vnodes(registry: &VnodeRegistry, owner: NodeId) -> Vec<u32>Expand description
Vnodes currently assigned to owner.
Used by the checkpoint coordinator to decide which vnodes’ durability
markers it is responsible for writing each epoch, and by the leader’s
epoch_complete gate to know the full set to check.